@@ -97,13 +97,21 @@ class OrderedAndRecieved(BASE,Template):
     work notes
     '''
     __tablename__='OrderedAndRecieved'
-    Name=Column(String,default=None)
-    ForWhom=Column(String,default=None)
+    TitleOrSubject=Column(String,default=None)
+    NameForWhom=Column(String,default=None)
     Description=Column(String,default=None)
-    oarid=Column(Integer,primary_key=True)
+    AddressForWhom=Column(String,default=None)
+    RecieptId=Column(String,default=None)
+    NanoId=Column(String,default=None)
     dtoe=Column(DateTime,default=datetime.now())
 
     #Organizational info.
+    payee_name=Column(String,default=None)
+    payor_name=Column(String,default=None)
+    what_is_the_address_worked_at=Column(String,default=None)
+    if_necessary_what_is_the_payors_address=Column(String,default=None)
+    did_the_payor_specify_restrictions_and_if_so_what_are_they=Column(String,default=None)
+    are_there_any_special_requirements_that_need_to_be_mentioned=Column(String,default=None)
     was_this_for_a_residence=Column(Boolean,default=None)
     was_this_for_a_business=Column(Boolean,default=None)
     what_was_the_organizations_name=Column(String,default=None)
@@ -112,14 +120,7 @@ class OrderedAndRecieved(BASE,Template):
     is_the_address_worked_at_lived_at_by_the_payor=Column(Boolean,default=None)
     is_the_address_worked_at_a_bussiness_address=Column(Boolean,default=None)
     is_the_address_worked_at_a_home_address=Column(Boolean,default=None)
-    payee_name=Column(String,default=None)
-    payor_name=Column(String,default=None)
-    what_is_the_address_worked_at=Column(String,default=None)
-    if_necessary_what_is_the_payors_address=Column(String,default=None)
-    did_the_payor_specify_restrictions_and_if_so_what_are_they=Column(String,default=None)
-    are_there_any_special_requirements_that_need_to_be_mentioned=Column(String,default=None)
-    How_are_wages_being_dispensed=Column(String,default=None)
-    
+    #Contact info
     payor_comments=Column(String,default=None)
     payee_comments=Column(String,default=None)
     payor_home_phone_1=Column(String,default=None)
@@ -145,11 +146,25 @@ class OrderedAndRecieved(BASE,Template):
     #678-659-9383
     #dmv error processing unit
     #let them know that i filled out my application on sept. 9.
-
+    How_are_wages_being_dispensed=Column(String,default=None)
+    
     RateOfPay=Column(Float,default=None)
     RateOfPayComment=Column(Float,default=None)
     RateOfPayBy=Column(String,default=None)
 
+    Amount_Paid=Column(Float,default=None)
+    Duration_For_Amount_Paid=Column(String,default=None)
+    Amount_Paid_Form=Column(String,default=None)
+
+    Paid_When_DT=Column(DateTime,default=None)
+    Shift_Started_DT=Column(DateTime,default=None)
+    Shift_Lunch_Start=Column(DateTime,default=False)
+    Shift_Lunch_End=Column(DateTime,default=False)
+    Shift_Ended_DT=Column(DateTime,default=None)
+    Shift_Labor_Breaks=Column(Text,default=None)
+    is_lunch_paid=Column(Boolean,default=False)
+    is_break_paid=Column(Boolean,default=False)
+
     #schedule 
     Was_This_A_Scheduled_Shift=Column(Boolean,default=True)
     ScheduledShiftDTOE=Column(DateTime,default=None)
@@ -191,7 +206,7 @@ class OrderedAndRecieved(BASE,Template):
 
     web_links=Column(Text,default=None)
     comment=Column(String,default=None)
-    
+    oarid=Column(Integer,primary_key=True)
     def __init__(self,*args,**kwargs):
         for k in kwargs:
             if k in [i.name for i in self.__table__.columns]:
